#!/usr/bin/env python3

"""
This mirror status checker determines whether CSC mirror is up-to-date with upstream
"""

import time
import sys
import requests

from projects import * # noqa
import json  # import json to read project info stored in json file


if __name__ == "__main__":
	"""projects = json.load(open('projects.json',))
	print(projects)

	for project in projects:
		print(project[0] + ":")
		print("CSC mirror: " + checker(project[1], project[3]))
		print("Official project: " + checker(project[2], project[3]))"""

	with open("data.json", "r", encoding="utf-8") as file:
		data = json.load(file)
		if sys.stdin.isatty():
			projects = data
		else:
			projects = [project.rstrip() for project in sys.stdin.readlines()]
		current_time = int(time.time())
		for project in projects:
			try:
				if project not in data:
					print(f"Failure: {project} does not exist")
					continue
				project_class = getattr(sys.modules[__name__], project)
				if project == "CPAN" or project == "ubuntu" or project == "ubuntu_releases" or project == "manjaro" or project == "mxlinux" or project == "mxlinux_iso" or project == "cran" or project == "ctan" or project == "gentooportage":
					checker_result = project_class.check(data, project, current_time)
					if checker_result:
						print(f"Success: {project} up-to-date")
					else:
						print(f"Failure: {project} out-of-sync")
					continue
				checker_result = project_class.check(data, project)
				if checker_result:
					data[project]["out_of_sync_since"] = None
				elif data[project]["out_of_sync_since"] is None:
					data[project]["out_of_sync_since"] = current_time
				elif current_time - data[project]["out_of_sync_since"] \
					> data[project]["out_of_sync_interval"]:
					print(f"Failure: {project} out-of-sync")
					continue
				print(f"Success: {project} up-to-date")
			except requests.exceptions.RequestException as err:
				print(f"Error: {project}\n{err}")
	with open("data.json", "w", encoding="utf-8") as file:
		json.dump(data, file, indent='\t')
